@@ -107,10 +107,19 @@ class SciAxes(Axes):
     def __init__(self,
                  x_range,
                  y_range,
+                 rectangle_style=True,
+                 width=None,
+                 height=None,
                  **kwargs):
         CoordinateSystem.__init__(self, **kwargs)
         VGroup.__init__(self, **kwargs)
 
+        if width is not None:
+            self.width = width
+        if height is not None:
+            self.height = height
+        self.rectangle_style = rectangle_style
+
         self.x_range[:len(x_range)] = x_range
         self.y_range[:len(y_range)] = y_range
 
@@ -126,8 +135,9 @@ class SciAxes(Axes):
         self._unit_y = self.y_axis.n2p(1) - self.y_axis.n2p(0)
 
         x_label_min, y_label_min = self.x_axis.x_min, self.y_axis.x_min
-        self.x_axis.shift(UP * self._unit_y * y_label_min)
-        self.y_axis.shift(RIGHT * self._unit_x * x_label_min)
+        if self.rectangle_style:
+            self.y_axis.shift(-UP * self._unit_y * y_label_min)
+            self.x_axis.shift(-RIGHT * self._unit_x * x_label_min)
 
         self.axes = VGroup(self.x_axis, self.y_axis)
         self.add(*self.axes)
@@ -145,7 +155,7 @@ class SciAxes(Axes):
         origin_x = self.x_axis.number_to_point(0)
         origin_y = self.y_axis.number_to_point(0)
 
-        result = np.array([origin_x[0], origin_y[1], 0])
+        result = np.array([origin_x[0], origin_y[1], origin_x[2]])
         for axis, coord, origin in zip(self.get_axes(), coords, [origin_x, origin_y]):
             result += (axis.number_to_point(coord) - origin)
         return result
@@ -162,3 +172,63 @@ class SciAxes(Axes):
         )
         graph.underlying_function = function
         return graph
+
+
+class SciAxes3D(SciAxes):
+    # WIP...
+    CONFIG = {
+        "dimension": 3,
+        "x_range": np.array([-6.0, 6.0, 1.0]),
+        "y_range": np.array([-5.0, 5.0, 1.0]),
+        "z_range": np.array([-4.0, 4.0, 1.0]),
+        "z_axis_config": {},
+        "z_normal": DOWN,
+        "height": None,
+        "width": None,
+        "depth": None,
+        "num_axis_pieces": 20,
+        "gloss": 0.5,
+    }
+
+    def __init__(self, x_range=None, y_range=None, z_range=None, **kwargs):
+        SciAxes.__init__(self, x_range, y_range, **kwargs)
+        if z_range is not None:
+            self.z_range[:len(z_range)] = z_range
+
+        z_axis = self.create_axis(
+            self.z_range,
+            self.z_axis_config,
+            self.depth,
+        )
+        z_axis.rotate(-PI / 2, UP, about_point=ORIGIN)
+        z_axis.rotate(
+            angle_of_vector(self.z_normal), OUT,
+            about_point=ORIGIN
+        )
+
+        self.axes.add(z_axis)
+        self.add(z_axis)
+        self.z_axis = z_axis
+
+        self._unit_z = self.z_axis.n2p(1) - self.z_axis.n2p(0)
+
+        z_label_min = self.z_axis.x_min
+        self.z_axis.shift(IN * self._unit_z * z_label_min)
+
+        for axis in self.axes:
+            axis.insert_n_curves(self.num_axis_pieces - 1)
+        self.add_coordinate_labels()
+        self.shift(-self.get_center())
+
+    def get_all_ranges(self):
+        return [self.x_range, self.y_range, self.z_range]
+
+    def coords_to_point(self, *coords):
+        origin_x = self.x_axis.number_to_point(0)
+        origin_y = self.y_axis.number_to_point(0)
+        origin_z = self.z_axis.number_to_point(0)
+
+        result = np.array([origin_x[0], origin_y[1], origin_z[2]])
+        for axis, coord, origin in zip(self.get_axes(), coords, [origin_x, origin_y, origin_z]):
+            result += (axis.number_to_point(coord) - origin)
+        return result
